searchData={"items":[{"type":"module","title":"accept_encoding_header","doc":"For parsing and negotiating Accept-Encoding headers.","ref":"accept_encoding_header.html"},{"type":"function","title":"accept_encoding_header.negotiate/2","doc":"Negotiates the most appropriate content_coding given the accept header","ref":"accept_encoding_header.html#negotiate/2"},{"type":"function","title":"accept_encoding_header.parse/1","doc":"Parses Accept-Encoding header, returns a list of content_codings.","ref":"accept_encoding_header.html#parse/1"},{"type":"type","title":"accept_encoding_header.accept_option/0","doc":"Accept options.","ref":"accept_encoding_header.html#t:accept_option/0"},{"type":"type","title":"accept_encoding_header.content_coding/0","doc":"Content codings.","ref":"accept_encoding_header.html#t:content_coding/0"},{"type":"type","title":"accept_encoding_header.media_range/0","doc":"Media ranges.","ref":"accept_encoding_header.html#t:media_range/0"},{"type":"module","title":"accept_header","doc":"HTTP Accept header parser and content-type negotiation helper","ref":"accept_header.html"},{"type":"function","title":"accept_header.negotiate/2","doc":"Negotiates the most appropriate content_type given the accept header\nand a list of alternatives.\n\n```\naccept_header:negotiate(\\\"text/*;q=0.3, text/html;q=0.7, text/html;level=1,\\\"\n                        \\\"text/html;level=2;q=0.4, */*;q=0.5\\\",\n                        [\\\"text/html;level=2\\\", \\\"text/html;level-3\\\"]).\n\\\"text/html;level-3\\\"\n```","ref":"accept_header.html#negotiate/2"},{"type":"function","title":"accept_header.parse/1","doc":"Parses Accept header, returns a list of media_ranges.\n\n```\naccept_header:parse(\\\"text/*;q=0.3, text/html;q=0.7, text/html;level=1,\\\"\n                    \\\"text/html;level=2;q=0.4, */*;q=0.5\\\").\n[{media_range,\\\"text\\\",\\\"*\\\",0.3,[]},\n {media_range,\\\"text\\\",\\\"html\\\",0.7,[]},\n {media_range,\\\"text\\\",\\\"html\\\",1,[{\\\"level\\\",\\\"1\\\"}]},\n {media_range,\\\"text\\\",\\\"html\\\",0.4,[{\\\"level\\\",\\\"2\\\"}]},\n {media_range,\\\"*\\\",\\\"*\\\",0.5,[]}]\n```","ref":"accept_header.html#parse/1"},{"type":"extras","title":"Overview","doc":"# Accept header(s) for Erlang/Elixir #\n\n[![Hex.pm](https://img.shields.io/hexpm/v/accept.svg?maxAge=2592000?style=plastic)](https://hex.pm/packages/accept)\n[![Hex.pm](https://img.shields.io/hexpm/dt/accept.svg?maxAge=2592000)](https://hex.pm/packages/accept)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/accept/)\n[![GitHub Actions](https://github.com/prometheus-erl/accept/actions/workflows/ci.yml/badge.svg)](https://github.com/prometheus-erl/accept/actions/workflows/ci.yml)\n[![Codecov](https://codecov.io/github/prometheus-erl/accept/graph/badge.svg?token=G9HB5UKNIY)](https://codecov.io/github/prometheus-erl/accept)","ref":"readme.html"},{"type":"extras","title":"TOC - Overview","doc":"- [Accept](#accept-header) \n- [Accept-Encoding](#accept-encoding-header)\n- [Contributing](#contributing) \n- [License](#license)","ref":"readme.html#toc"},{"type":"extras","title":"Headers - Overview","doc":"","ref":"readme.html#headers"},{"type":"extras","title":"Accept - Overview","doc":"[RFC](https://tools.ietf.org/html/rfc7231#section-5.3.2)\n\n#### Parsing\n\n```erlang\n\n1> accept_header:parse(\"text/*;q=0.3, text/html;q=0.7, text/html;level=1,\"\n                       \"text/html;level=2;q=0.4, */*;q=0.5\").\n[{media_range,\"text\",\"*\",0.3,[]},\n {media_range,\"text\",\"html\",0.7,[]},\n {media_range,\"text\",\"html\",1,[{\"level\",\"1\"}]},\n {media_range,\"text\",\"html\",0.4,[{\"level\",\"2\"}]},\n {media_range,\"*\",\"*\",0.5,[]}]\n\n```\n\n#### Content Negotiation\n\n```erlang\n\n2> accept_header:negotiate(\"text/*;q=0.3, text/html;q=0.7, text/html;level=1,\"\n                           \"text/html;level=2;q=0.4, */*;q=0.5\",\n                           [\"text/html;level=2\", \"text/html;level-3\"]).\n\"text/html;level-3\"\n\n```\n\n`\"text/html;level-3\"` returned because `\"text/html;level=2\"` matches to\n`text/html;level=2;q=0.4` with score 0.4 and most specific match for\n`\"text/html;level-3\"` is `text/html;q=0.7` with score 0.7.\n\n```erlang\n\n3> accept_header:negotiate(\"application/xml,application/xhtml+xml,\"\n3>                         \"text/html;q=0.9,text/plain;q=0.8,image/png,image/*;q=0.9,*/*;q=0.5\",\n3>                         [\"text/n3\",\n3>                          \"application/rdf+xml\"]).\n\"text/n3\"\n\n```\n\nNegotiate preserves user-defined order for equally scored alternatives.","ref":"readme.html#accept"},{"type":"extras","title":"Accept-Encoding - Overview","doc":"[RFC](https://tools.ietf.org/html/rfc7231#section-5.3.4)\n\n#### Parsing\n\n```erlang\n\n1> accept_encoding_header:parse(\"gzip;q=1.0, identity; q=0.5, *;q=0\").\n[{content_coding,\"gzip\",1.0,[]},\n {content_coding,\"identity\",0.5,[]},\n {content_coding,\"*\",0,[]}]\n\n```\n\n#### Content Negotiation\n\n```erlang\n\n1> accept_encoding_header:negotiate(\"compress, gzip\",\n1>                                  [\"identity\", \"compress\"]).\n\"compress\"\n\n2> accept_encoding_header:negotiate(\"gzip;q=1.0, identity; q=0.5, *;q=0\",\n2>                                  [\"identity\", \"sdc\", \"gzip\", \"compress\"]).\n\"gzip\"\n\n3> accept_encoding_header:negotiate(\"compress, gzip, *;q=0\",\n3>                                  [\"qwe\"]).\nundefined\n\n```\n\nNegotiate preserves user-defined order for equally scored alternatives.","ref":"readme.html#accept-encoding"},{"type":"extras","title":"License","doc":"The MIT License (MIT)\n\nCopyright (c) 2016, Ilya Khaprov  .\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}